==> sdata-plugin-scripts-1.0.8.tgz: package/lib/scripts/predev/writeInformation.js <==
"use strict";

var exec = require("child_process").execSync;
var os = require("os");
var fs = require("fs");
var path = require("path");
var cwd = process.cwd();
var information = require(cwd + "/information.json");
module.exports = function writeInformation() {
  information.developers = getDevelopers();
  information.ipAdress = getIpAddress();
  fs.writeFileSync(path.resolve(cwd + "/information.json"), JSON.stringify(information, null, 2), "utf8");
};
function getDevelopers() {
  var preDevelopers = information.developers;
  var developers = "";
  var currentDeveloper = "";
  try {
    currentDeveloper = exec("git config user.name", {
      "encoding": "utf8"
    }).replace("\n", "");
  } catch (e) {
    console.log(e);
  }
  if (preDevelopers) {
    if (preDevelopers.split(",").includes(currentDeveloper)) {
      developers = preDevelopers;
    } else {
      developers = "".concat(preDevelopers, ",").concat(currentDeveloper);
    }
  } else {
    developers = currentDeveloper;
  }
  return developers;
}
function getIpAddress() {
  var ifaces = os.networkInterfaces();
  for (var dev in ifaces) {
    var iface = ifaces[dev];
    for (var i = 0; i < iface.length; i++) {
      var _iface$i = iface[i],
        family = _iface$i.family,
        address = _iface$i.address,
        internal = _iface$i.internal,
        mac = _iface$i.mac;
      if (family === "IPv4" && address !== "127.0.0.1" && !internal && mac !== "00:00:00:00:00:00") {
        return address;
      }
    }
  }
}

==> sdata-plugin-scripts-1.0.34.tgz: package/lib/scripts/predev/writeInformation.js <==
"use strict";

var exec = require("child_process").execSync;
var os = require("os");
var fs = require("fs");
var path = require("path");
var cwd = process.cwd();
var information = require(__dirname + "/../information.json");
module.exports = function writeInformation() {
  information.developers = getDevelopers();
  information.ipAdress = getIpAddress();
  fs.writeFileSync(path.resolve(__dirname + "/../information.json"), JSON.stringify(information, null, 2), "utf8");
};
function getDevelopers() {
  var preDevelopers = information.developers;
  var developers = "";
  var currentDeveloper = "";
  try {
    currentDeveloper = exec("git config user.name", {
      "encoding": "utf8"
    }).replace("\n", "");
  } catch (e) {
    console.log(e);
  }
  if (preDevelopers) {
    if (preDevelopers.split(",").includes(currentDeveloper)) {
      developers = preDevelopers;
    } else {
      developers = "".concat(preDevelopers, ",").concat(currentDeveloper);
    }
  } else {
    developers = currentDeveloper;
  }
  return developers;
}
function getIpAddress() {
  var ifaces = os.networkInterfaces();
  for (var dev in ifaces) {
    var iface = ifaces[dev];
    for (var i = 0; i < iface.length; i++) {
      var _iface$i = iface[i],
        family = _iface$i.family,
        address = _iface$i.address,
        internal = _iface$i.internal,
        mac = _iface$i.mac;
      if (family === "IPv4" && address !== "127.0.0.1" && !internal && mac !== "00:00:00:00:00:00") {
        return address;
      }
    }
  }
}
